@@ -20,8 +20,10 @@ test_that("Does monte_carlo function give benchmark results?", {
                         custom_indicator = NULL,
                         na.rm = TRUE)
   # Fixed optimal parameter and shift (benchmark values)
-  ebp_optpar_bc <- read.csv2("EBP/ebp_optpar_bc.csv", sep = ",")  
-  ebp_shift_bc  <- read.csv2("EBP/ebp_shift_bc.csv", sep = ",")
+  ebp_optpar_bc <- read.csv2("EBP/ebp_optpar_bc.csv", sep = ",", 
+                             stringsAsFactors = TRUE)  
+  ebp_shift_bc  <- read.csv2("EBP/ebp_shift_bc.csv", sep = ",", 
+                             stringsAsFactors = TRUE)
   
   lambda <- as.numeric(as.character(ebp_optpar_bc[,"Optpar"]))
   shift  <- as.numeric(as.character(ebp_shift_bc))
@@ -63,7 +65,8 @@ test_that("Does monte_carlo function give benchmark results?", {
                                       )
 
   # Load benchmark point estimates
-  ebp_point_bc <- read.csv2("EBP/ebp_point_bc.csv", sep = ",")
+  ebp_point_bc <- read.csv2("EBP/ebp_point_bc.csv", sep = ",", 
+                            stringsAsFactors = TRUE)
  
   # compare 10% quantile
   expect_equal(point[,"Quantile_10"],
